@@ -1,7 +1,8 @@
 import torch
 import torch.nn as nn
 from math import pi as PI
-import util as util
+import Angular_Deviation_Diffuser.util as util
+
 
 def wrap(x):
     return torch.remainder(x + PI, 2 * PI) - PI
