@@ -13,7 +13,7 @@ from pyrosetta.rosetta.core.scoring.func import HarmonicFunc
 
 
 
-def refine_conformations(pdb_file):
+def refine_conformations(pdb_file,refine_pdb_file):
     pyrosetta.init("-constant_seed -jran 1111")
     pose = pose_from_file(pdb_file)
     scorefxn = get_score_function(True)
@@ -34,7 +34,7 @@ def refine_conformations(pdb_file):
     fast_relax.max_iter(1000)
     fast_relax.ramp_down_constraints(True)
     fast_relax.apply(pose)
-    pose.dump_pdb(f'{pdb_file}_optimized_structure.pdb')
+    pose.dump_pdb(f'{refine_pdb_file}')
 
 
 
